# eightball
A python machine learning classification toolbox.

Packages estimator object, imputator object, and training data into a model object. Includes a suite of tools to assist in performing common evaluation and model optimization routines (cross validation, grid search, feature reduction, etc.) and visualizing the results.
